# Package Description

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

This pacakge is just for my self


# Change Log 

* 2021-07-07
	* Include two function scripts

* 2021-07-08
	* bug fixed
	* new functions added